@@ -25,9 +25,12 @@ my $MOD_PERL = 0;
 if (exists $ENV{MOD_PERL}) {
   eval "require mod_perl";
   if (defined $mod_perl::VERSION) {
-    if ($mod_perl::VERSION >= 1.99) {
+    my $float = $mod_perl::VERSION;
+    $float = ~ s/^.+?([\d.]+).+$/$1/;
+    if ($float >= 1.99) {
       $MOD_PERL = 2;
       require Apache::RequestUtil;
+      eval "require APR::Table";  # Changing APIs? I hope not.
     } else {
       $MOD_PERL = 1;
       require Apache;
@@ -199,7 +202,7 @@ sub value {
 sub domain {
     my $self = shift;
     my $domain = shift;
-    $self->{'domain'} = $domain if defined $domain;
+    $self->{'domain'} = lc $domain if defined $domain;
     return $self->{'domain'};
 }
 
@@ -220,7 +223,7 @@ sub expires {
 sub max_age {
   my $self = shift;
   my $expires = shift;
-  $self->{'max-age'} = CGI::Util::expire_calc($expires)-time if defined $expires;
+  $self->{'max-age'} = CGI::Util::expire_calc($expires)-time() if defined $expires;
   return $self->{'max-age'};
 }
 
